@@ -22,13 +22,14 @@ def get_dir_hashes(path):
 def check_2_libs_actual():
     global_path, local_path = get_libs_paths()
 
-    global_fift_hashes = get_dir_hashes(f"{global_path}/fift-libs")
-    local_fift_hashes = get_dir_hashes(f"{local_path}/fift-libs")
+    global_fift_hashes = get_dir_hashes(os.path.abspath(f"{global_path}/fift-libs"))
+    local_fift_hashes = get_dir_hashes(os.path.abspath(f"{local_path}/fift-libs"))
 
-    global_func_hashes = get_dir_hashes(f"{global_path}/func-libs")
-    local_func_hashes = get_dir_hashes(f"{local_path}/func-libs")
+    global_func_hashes = get_dir_hashes(os.path.abspath(f"{global_path}/func-libs"))
+    local_func_hashes = get_dir_hashes(os.path.abspath(f"{local_path}/func-libs"))
 
     return global_fift_hashes == local_fift_hashes and global_func_hashes == local_func_hashes
 
+
 def get_libs_paths():
-    return f"{project_root}/lib", user_config_dir('toncli')
\ No newline at end of file
+    return os.path.abspath(f"{project_root}/lib"), user_config_dir('toncli')
